@@ -1,6 +1,6 @@
 /*
 SMS Server Tools
-Copyright (C) 2000 Stefan Frings
+Copyright (C) Stefan Frings
 
 This program is free software unless you got it under another license directly
 from the author. You can redistribute it and/or modify it under the terms of 
@@ -8,7 +8,7 @@ the GNU General Public License as published by the Free Software Foundation.
 Either version 2 of the License, or (at your option) any later version.
 
 http://www.isis.de/members/~s.frings
-mailto:s.frings@mail.isis.de
+mailto:stefan.frings@vodafone.de
 */
 
 #include "locking.h"
@@ -16,10 +16,11 @@ mailto:s.frings@mail.isis.de
 #include <sys/stat.h>
 #include <string.h>
 #include <fcntl.h>
+#include <limits.h>
 
 int lockfile(const char* const filename)
 {
-  char lockfilename[256];
+  char lockfilename[PATH_MAX];
   int lockfile;
   struct stat statbuf;
   char pid[20];
@@ -44,19 +45,19 @@ int lockfile(const char* const filename)
 
 int islocked(const char* const filename)
 {
-  char lockfilename[256];
+  char lockfilename[PATH_MAX];
   struct stat statbuf;
   strcpy(lockfilename,filename);
   strcat(lockfilename,".LOCK");
   if (stat(lockfilename,&statbuf))
     return 0;
   else
-    return 1;  
+    return 1;
 }
 
 int unlock(const char* const filename)
 {
-  char lockfilename[256];
+  char lockfilename[PATH_MAX];
   struct stat statbuf;
   strcpy(lockfilename,filename);
   strcat(lockfilename,".LOCK");
