@@ -169,6 +169,29 @@ void initmodem()
   int retries=0;
   int success=0;
 
+  if (! quickinit)
+  {
+    writelogfile(LOG_INFO,"Checking if modem is ready");
+    retries=0;
+    do
+    {
+      retries++;
+      put_command("\x1A\r",answer,sizeof(answer),5,0);
+      put_command("AT\r",answer,sizeof(answer),50,"OK");
+      if (strstr(answer,"OK"))
+        writelogfile(LOG_INFO,"Modem is ready");
+      else
+        writelogfile(LOG_NOTICE,"Modem is not ready, retry");
+    }
+    while ((retries<=10) && (! strstr(answer,"OK")));
+    if (! strstr(answer,"OK"))
+    {
+      writelogfile(LOG_ERR,"Modem is not ready to answer commands");
+      alarm_handler(LOG_ERR,"","Modem is not ready to answer commands");
+      exit(2);
+    }
+  }
+
   if ((! quickinit) && pin[0])
   {
     writelogfile(LOG_INFO,"Checking if modem needs PIN");
